// animations
var animationPause = 20; // milliseconds
var initialDelay = 750; // milliseconds
var defaultSpeed = 20; // pixels per frame

var maxLeftMargin = 10;
var minLeftMargin = -230;
var currentMargin = maxLeftMargin;
var currentMarginSpeed = 0;
 
var currentTimerId = null;

function updateSidebarAnimation() {
   currentMargin += currentMarginSpeed;
   
   var stopAnim = true;
   if ( currentMargin <= minLeftMargin )
      currentMargin = minLeftMargin;
   else if ( currentMargin >= maxLeftMargin )
      currentMargin = maxLeftMargin;
   else
      stopAnim = false;

   if ( stopAnim ) {
      clearInterval(currentTimerId);
      currentTimerId = null;
   }

   var body = document.getElementsByTagName('body')[0];
   body.style.marginLeft = currentMargin + "px";        
}

function addSidebarAnimation(speed) {
   currentMarginSpeed = speed;
   if ( currentTimerId == null )
      currentTimerId = setInterval('updateSidebarAnimation()', animationPause);
}

function getViewportWidth() {
   if ( typeof(window.innerWidth) == 'number' )
      return window.innerWidth;         // Non-IE
   else if ( document.documentElement && ( document.documentElement.clientWidth || document.documentElement.clientHeight ) )
      return  document.documentElement.clientWidth;       // IE 6+ in 'standards compliant mode'
   else if ( document.body && ( document.body.clientWidth || document.body.clientHeight ) )
      return document.body.clientWidth;    // IE 4 compatible
}

function getViewportHeight() {
   if ( typeof(window.innerHeight) == 'number' )
      return window.innerHeight;         // Non-IE
   else if ( document.documentElement && ( document.documentElement.clientWidth || document.documentElement.clientHeight ) )
      return  document.documentElement.clientHeight;       // IE 6+ in 'standards compliant mode'
   else if ( document.body && ( document.body.clientWidth || document.body.clientHeight ) )
      return document.body.clientHeight;    // IE 4 compatible
}

function autoHideSidebar() {
   setInterval("autoHideSidebarNow()", initialDelay);
}

function autoHideSidebarNow() {
   if ( document.getElementById('theOneAndOnlySidebar') == null )
      return;

   var maxWidth = 0;
   // objects
   var objs = document.getElementsByTagName('object');
   for ( var i = 0; i < objs.length; i++ ) {
      var w = Number(objs[i].getAttribute('width'));
      if ( w > maxWidth ) maxWidth = w;
   }
   // iframes - only use explicit settings
   var iframes = document.getElementsByTagName('iframe');
   for ( i = 0; i < iframes.length; i++ ) {
      var m = iframes[i].style.width.match(/(\d+)\s*px/);
      if ( m ) {
         var wid = Number(m[1]);
         if ( wid > maxWidth ) maxWidth = wid;
      }
   }
   // is the width too big?
   if ( maxWidth + 300 > getViewportWidth() )
      startHidingSidebar();
   else
   	  stopHidingSidebar();
}

function getMouseX(event) {
   if ( !event ) 
      event = window.event;
   if ( typeof(event.pageX) == 'number' )
      return event.pageX;
   return event.clientX;
}

var autoHideMode = false;

window.onbeforeunload = function () {
   autoHideMode = false;
}

function startHidingSidebar() {
   if ( autoHideMode ) return;
   autoHideMode = true;
   
   addSidebarAnimation(-defaultSpeed);
   
   var sb = document.getElementById('theOneAndOnlySidebar');
   if ( sb != null ) {
      sb.onmouseover = function () {
         addSidebarAnimation(defaultSpeed); 
      };  
      sb.onmouseout = function (event) { 
         if ( getMouseX(event) > maxLeftMargin ) addSidebarAnimation(-defaultSpeed); 
      };  
   }
}

function stopHidingSidebar() {
   autoHideMode = false;
   
   addSidebarAnimation(defaultSpeed);
   
   var sb = document.getElementById('theOneAndOnlySidebar');
   if ( sb != null ) {
      sb.onmouseover = function () { };  
      sb.onmouseout = function () { };
   }
}
